@@ -1,6 +1,6 @@
-набір = set
-строка = str
+множина = set
+текст = str
 словник = dict
 список = list
-булево = bool
+логічне = bool
 число = int
